-- ===================================================================================================
--
-- Examples of an Ada Case Statement.  No break statement required!
--
-- ===================================================================================================
--
procedure Ada_Distilled_4_2_3 is

   type Color is (White, Red, Orange, Yellow, Chartreuse, Green, Blue, Indigo, Violet, Black, Brown); 	


   function  Decide (C : Color) return  Integer is           --   1 Simple function declaration
      Result : Integer := 0;	                               --   2 Local variable
   begin	-- Decide	                                     --   3 Comment the begin statement
      case C is	                                           --   4 Start a case statement
         when Red =>	                                     --   5 One of the enumerated values
            begin	                                           --   6  An unlabeled begin ... end sequence; see 4.4
               null;                                         --   7.1sequence-of-statements	
                                                             --   7.2 Any sequence of Ada statements
            end;	                                           --   8 Unlabeled end statement
         when Blue =>	                                     --   9 One of the enumerated values
            Label_1:	                                     --  10 Better style; use a block label
            begin                                            --  11 Alternative:  consider calling nested subprogram
               null;                                         --  12 sequence-of-statements
            end Label_1;                                     --  13 The label is required for the end statement
         when  others =>                                     --  14 Ada requires others if some choices are unmentioned
            Label_2:                                         --  15 Yes. Still using the label; label an embedded begin block
            begin	                                           --  16.1 
               null;                                         --  16.2 handled-sequence-of-statements
               	                                           --  17 We expect a local exception handler.
            exception	                                     --  18 This is a good use of begin...end blocks
               when Constraint_Error =>                      --  18.1
                  null;                                      --  18.2 sequence-of-statements
                  	                                     --  19 The exception handling statements
            end Label_2;	                               --  20 The compiler will look for this
      end case;	                                           --  21 Scope terminator is required
      return Result;	                                     --  22 Compiler will look for a return statement
   end Decide;	                                           --  23 As usual, label the end statement


   function Evaluate (C : Color) return  Integer is         --  1 Simple function declaration
      Result : Integer := 0;	                              --  2 Local variable
   begin	-- Evaluate	                                    --  3 Comment the begin statement
      case C is	                                          --  4 Start a case statement
         when Red => Result := 1;	                        --  5 The => is an association symbol
         when Blue =>Result := 2;	                        --  6 Am I blue? Set result to 2
         when Black .. Brown => Result := 3;                --  7 For black through brown ...
         when Orange | Indigo => Result := 4;               --  8 For either orange or indigo
         when  others => Result := 5;                       --  9 others required for unspecified cases.
      end case;	                                          -- 10 Must use others if any cases are not specified
      return Result;	                                    -- 11 Compiler will look for a return statement
   end Evaluate;	                                          -- 12 As usual, label the end statement
begin
   null;
end Ada_Distilled_4_2_3;