-- ========== String_To_Scalar_Demonstration ===========-- String_To_Scalar_Demonstration.adb  by Richard Riehle-- This program demonstrates several ways to convert a -- a string to a scalar value.
-- 
-- =====================================================
with Ada.Text_Io;
with Ada.Integer_Text_Io;
with Ada.Float_Text_Io;
use  Ada;
procedure String_To_Scalar_Demonstration is
   type Spectrum is 
         (Red,    
          Orange, 
          Yellow, 
          Green,  
          Blue,   
          Indigo, 
          Violet); 
   type Unsigned is mod 2**8; 
   Num   : Integer  := 0;
   Fnum  : Float    := 0.0;
   Color : Spectrum := Blue;
   Mnum  : Unsigned := 0;
   Text  : String(1..10)  := (others => '*');
   Text_Integer  : String := "451";
   Text_Float    : String := "360.0";
   Text_Color    : String := "Orange";
   Text_Unsigned : String := "42";
   Integer_Last  : Natural;
   Float_Last    : Natural;
   Spectrum_Last : Natural;
   Modular_Last  : Natural;
   package Sio is new Text_Io.Enumeration_Io(Enum => Spectrum);
   package Mio is new Text_Io.Modular_Io    (Num  => Unsigned);
   package Iio is new Text_Io.Integer_Io    (Num  => Integer);
   package Fio is new Text_Io.Float_Io      (Num  => Float);
begin
   Text_Io.Put_Line("The String Values are: ");
   Text_Io.Put("Orange for Enumerated Type          ");
   Text_Io.Put_Line("451  for Integer Type  ");
   Text_Io.Put("360.0  for Float Type               ");
   Text_Io.Put_Line("42  for Unsigned Type  ");
   Text_Io.New_Line;
   -- Example 1; using the Value attribute
   Text_Io.New_Line;
   Text_Io.Put_Line("   >>>> Example 1; Using 'Value Attribute <<<< ");
   Color := Spectrum'Value(Text_Color);
   Num   := Integer'Value(Text_Integer);
   Fnum  := Float'Value(Text_Float);
   Mnum  := Unsigned'Value(Text_Unsigned);
   Sio.Put(Color);   Text_Io.New_Line;
   Iio.Put(Num);     Text_Io.New_Line;
   Fio.Put(Fnum);    Text_Io.New_Line;
   Mio.Put(Mnum);    Text_Io.New_Line;
   Text_Io.New_Line;
   -- Example 2; using the procedures of pre-instantiated packages
   Text_Io.Put_Line(
      "   >>>> Example 2; using pre-instantiated packages <<<< " );
   Integer_Text_Io.Get(From => Text_Integer,
      Item => Num,
      Last => Integer_Last);
   Float_Text_Io.Get(From => Text_Float,
      Item => Fnum,
      Last => Float_Last);
   Integer_Text_Io.Put(Num); Text_Io.New_Line;
   Float_Text_Io.Put  (Fnum, Fore => 3, Aft => 3, Exp => 0);
   Text_Io.New_Line(2);
   -- Example 3; using your own instantiated packages
   Text_Io.Put_Line("   >>>> Example 3; Using own instantiations <<<< ");
   Text_Io.New_Line;
   Sio.Get(From => Text_Color, Item => Color, Last => Spectrum_Last);
   Mio.Get(From => Text_Unsigned, Item => Mnum, Last => Modular_Last);
   Iio.Get(From => Text_Integer, Item => Num, Last => Integer_Last);
   Fio.Get(From => Text_Float, Item => Fnum, Last => Float_Last);
   -- Now Write the Results to the Screen
   Sio.Put(Item => Color);  Text_Io.New_Line;
   Iio.Put(Item => Num);    Text_Io.New_Line;
   Fio.Put(Item => Fnum, Fore => 3, Aft => 3, Exp => 0);
   Text_Io.New_Line;
   Mio.Put(Item => Mnum);
   Text_Io.New_Line(2);
   Text_Io.Put_Line(Text & " End of String_To_Scalar_Demonstration " & Text);
end String_To_Scalar_Demonstration;
